/*
   FALCON - The Falcon Programming Language.
   FILE: verion.h

   Falcon clt
   -------------------------------------------------------------------
   Author: Giancarlo Niccolai
   Begin: 2007-07-25


   -------------------------------------------------------------------
   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)

   See LICENSE file for licensing details.
*/

#ifndef FDIS_VERSION_H
#define FDIS_VERSION_H

#define FDIS_VERSION_MAJOR        0
#define FDIS_VERSION_MINOR        8 
#define FDIS_VERSION_REVISION     10

#endif

/* end of version.h */
